<?php

namespace Drupal\drd\Entity\AccessControlHandler;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Entity\EntityAccessControlHandler;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Access controller for the Project entity.
 *
 * @see \Drupal\drd\Entity\Project.
 */
class Project extends EntityAccessControlHandler {

  /**
   * {@inheritdoc}
   */
  protected function checkAccess(EntityInterface $entity, $operation, AccountInterface $account) {
    /** @var \Drupal\drd\Entity\ProjectInterface $entity */
    switch ($operation) {
      case 'view':
        if (!$entity->isPublished()) {
          return AccessResult::allowedIfHasPermission($account, 'drd.view unpublished project entities');
        }
        return AccessResult::allowedIfHasPermission($account, 'drd.view published project entities');

      case 'update':
        return AccessResult::allowedIfHasPermission($account, 'drd.edit project entities');

      case 'delete':
        return AccessResult::allowedIfHasPermission($account, 'drd.delete project entities');
    }

    return AccessResult::allowed();
  }

  /**
   * {@inheritdoc}
   */
  protected function checkCreateAccess(AccountInterface $account, array $context, $entity_bundle = NULL) {
    return AccessResult::allowedIfHasPermission($account, 'drd.add project entities');
  }

}
